<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:xd="http://www.oxygenxml.com/ns/doc/xsl" xmlns:xs="http://www.w3.org/2001/XMLSchema"
    xmlns:func="http://www.oxygenxml.com/doc/xsl/functions" version="3.0">
    <xd:doc>
        <xd:desc>
            <xd:p>This is the value that indicates we have a split by location.</xd:p>
        </xd:desc>
    </xd:doc>
    <xsl:variable name="chunkValueLocation" as="xs:string">location</xsl:variable>
  
    <xd:doc>
        <xd:desc>
            <xd:p>Get the title of the html page by analyzing the <xd:ref name="splitInfo"
                    type="variable">splitInfo</xd:ref> element.</xd:p>
        </xd:desc>
        <xd:param name="splitInfo">the split criterion</xd:param>
        <xd:return>The title of the html page.</xd:return>
    </xd:doc>
    <xsl:function name="func:getTitleFromSplitInfo" as="xs:string"
        xmlns:xs="http://www.w3.org/2001/XMLSchema">
        <xsl:param name="splitInfo"/>
        <xsl:choose>
            <xsl:when test="$splitInfo/@criteria = $chunkValueLocation">
                <xsl:value-of select="concat('Stylesheet documentation for: ', $splitInfo/@value)"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of
                    select="concat('Stylesheet documentation for: ', $splitInfo/parent::node()/stylesheet[@type = 'main']/qname)"
                />
            </xsl:otherwise>
        </xsl:choose>
    </xsl:function>

    <xsl:function name="func:substring-before-last" as="xs:string">
        <xsl:param name="string"/>
        <xsl:param name="searched"/>
        <xsl:variable name="toReturn">
            <xsl:choose>
                <xsl:when test="contains($string, $searched)">
                   
                </xsl:when>
                <xsl:otherwise/>
            </xsl:choose>
        </xsl:variable>
        <xsl:value-of select="$toReturn"/>
    </xsl:function>
    <xd:doc>
        <xd:desc>
            <xd:p>Get the substring after the last occurrence of the given substring.</xd:p>
        </xd:desc>
    </xd:doc>
    <xsl:function name="func:substring-after-last" as="xs:string">
        <xsl:param name="string"/>
        <xsl:param name="searched"/>
        <xsl:variable name="toReturn">
            <xsl:choose>
                <xsl:when test="contains($string, $searched)">
                    <!-- ...... -->
                </xsl:when>
                <xsl:otherwise/>
            </xsl:choose>
        </xsl:variable>
        <xsl:value-of select="$toReturn"/>
    </xsl:function>

    <xd:doc>
        <xd:desc>
            <xd:p>The entry point template. </xd:p>
            <xd:p>It creates the output files depending on the split criterion and copies the CSS
                file to the main file location.</xd:p>
        </xd:desc>
    </xd:doc>
    <xsl:template match="xslDocumentation">
        <xsl:if test="stylesheet[@type = 'main']">
            <!-- This way we make sure the CSS will only be copied once-->
            <!-- .......... -->
        </xsl:if>
    </xsl:template>
    
    <xsl:template name="indexGroupByComponent">
        <xsl:param name="refSeq" required="yes"/>
        <xsl:param name="prefix"/>
        <!-- Use the horizontal layout. -->
    </xsl:template>
    
    <xd:doc>
        <xd:desc>
            <xd:p>Draws a table with rounded corners that will contain all the properties of a
                component.</xd:p>
        </xd:desc>
    </xd:doc>
    <xsl:template name="makeRoundedTable">
        <xsl:param name="content" required="yes"/>
        <xsl:param name="countTableRows" required="yes" as="xs:boolean"/>
        <!-- ............ -->
    </xsl:template>
    
    <xd:doc>
        <xd:desc>
            <xd:p>Creates a table that contains information about the <xd:b>attributes</xd:b> of an
                attribute-set component. </xd:p>
        </xd:desc>
        <xd:param name="boxID">
            <xd:p>The id of the current attribute.</xd:p>
        </xd:param>
        <xd:param name="currentCharacter">
            <xd:p>The current character.</xd:p>
        </xd:param>
        <xd:param name="chunkSize">
            <xd:p>The maximum number of rows that a table will have.</xd:p>
        </xd:param>
    </xd:doc>
    <xsl:template name="attributes">
        <xsl:param name="boxID"/>
        <td class="fCol">
            <div class="flL">Attributes</div>
            <div class="flR">
                <xsl:copy-of select="$boxID"/>
            </div>
        </td>
    </xsl:template>
</xsl:stylesheet>
